@@ -1,7 +1,7 @@
 # ABSTRACT: Client to a {JSON:API} service (http://jsonapi.org/) v1.0
 package PONAPI::Client;
 
-our $VERSION = '0.002001';
+our $VERSION = '0.002002';
 
 use Moose;
 
@@ -37,6 +37,12 @@ has send_version_header => (
     default => sub { 1 },
 );
 
+has send_escape_values_header => (
+    is      => 'ro',
+    isa     => 'Bool',
+    default => sub { 1 },
+);
+
 
 ### public methods
 
@@ -121,6 +127,10 @@ sub _send_ponapi_request {
                         ? ( 'X-PONAPI-Client-Version' => '1.0' )
                         : ()
                     ),
+                    ( $self->send_escape_values_header
+                        ? ( 'X-PONAPI-Escaped-Values' => '1' )
+                        : ()
+                    ),
                 ],
                 parse_chunked => 1,
             });
@@ -166,7 +176,7 @@ PONAPI::Client - Client to a {JSON:API} service (http://jsonapi.org/) v1.0
 
 =head1 VERSION
 
-version 0.002001
+version 0.002002
 
 =head1 SYNOPSIS
 
