@@ -1,11 +1,15 @@
 # ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
 package PONAPI::Utils::URI;
 
+use strict;
+use warnings;
+
 use URI;
 use URI::QueryParam;
+use URI::Escape qw( uri_escape_utf8 );
 
 use parent qw< Exporter >;
-@EXPORT_OK = qw< to_uri >;
+our @EXPORT_OK = qw< to_uri >;
 
 sub to_uri {
     my ( $data ) = @_;
@@ -20,7 +24,7 @@ sub to_uri {
 
         if ( ref $d_v ne 'HASH' ) {
             $u->query_param( $d_k =>
-                             join ',' => ( ref $d_v eq 'ARRAY' ? @{$d_v} : $d_v ) );
+                             join ',' => map { uri_escape_utf8($_) } ( ref $d_v eq 'ARRAY' ? @{$d_v} : $d_v ) );
             next;
         }
 
@@ -32,7 +36,7 @@ sub to_uri {
                 unless !ref $v or ref $v eq 'ARRAY';
 
             $u->query_param( $d_k . '[' . $k . ']' =>
-                             join ',' => ( ref $v eq 'ARRAY' ? @{$v} : $v ) );
+                             join ',' => map { uri_escape_utf8($_) } ( ref $v eq 'ARRAY' ? @{$v} : $v ) );
         }
     }
 
@@ -53,7 +57,7 @@ PONAPI::Utils::URI - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.
 
 =head1 VERSION
 
-version 0.002001
+version 0.002002
 
 =head1 AUTHORS
 
